@@ -32,7 +32,7 @@ class MlflowCreator(TemplateCreator):
         self.MLFLOW_XGBOOST_TEMPLATE_VERSION = load_mlf_core_template_version('mlflow-xgboost', self.AVAILABLE_TEMPLATES_PATH)
         self.MLFLOW_XGBOOST_DASK_TEMPLATE_VERSION = load_mlf_core_template_version('mlflow-xgboost_dask', self.AVAILABLE_TEMPLATES_PATH)
 
-    def create_template(self, dot_mlf_core: dict or None):
+    def create_template(self, path: Path, dot_mlf_core: dict or None):
         """
         Handles the mlflow domain. Prompts the user for the language, general and domain specific options.
         """
@@ -78,7 +78,7 @@ class MlflowCreator(TemplateCreator):
             self.cli_struct.language), f'mlflow-{self.cli_struct.language.lower()}'
 
         # perform general operations like creating a GitHub repository and general linting
-        super().process_common_operations(domain='mlflow', language=self.cli_struct.language, dot_mlf_core=dot_mlf_core)
+        super().process_common_operations(path=Path(path).resolve(), domain='mlflow', language=self.cli_struct.language, dot_mlf_core=dot_mlf_core)
 
     def mlflow_pytorch_options(self, dot_mlf_core: dict or None):
         """ Prompts for mlflow-pytorch specific options and saves them into the MlflowTemplateStruct """
