@@ -1,12 +1,10 @@
 import os
 import sys
+import logging
 from collections import OrderedDict
-
 import shutil
 import re
 import tempfile
-
-import mlf_core
 import requests
 from distutils.dir_util import copy_tree
 from pathlib import Path
@@ -14,6 +12,7 @@ from dataclasses import asdict
 from ruamel.yaml import YAML
 from cookiecutter.main import cookiecutter
 
+import mlf_core
 from mlf_core.custom_cli.questionary import mlf_core_questionary_or_dot_mlf_core
 from mlf_core.util.dir_util import delete_dir_tree
 from mlf_core.create.github_support import create_push_github_repository, load_github_username, is_git_repo
@@ -24,6 +23,8 @@ from mlf_core.config.config import ConfigCommand
 from mlf_core.common.load_yaml import load_yaml_file
 from rich import print
 
+log = logging.getLogger(__name__)
+
 
 class TemplateCreator:
     """
@@ -35,22 +36,36 @@ class TemplateCreator:
     def __init__(self, creator_ctx: MlfcoreTemplateStruct):
         self.WD = os.path.dirname(__file__)
         self.TEMPLATES_PATH = f'{self.WD}/templates'
-        self.COMMON_FILES_PATH = f'{self.TEMPLATES_PATH}/common_files'
+        self.COMMON_FILES_PATH = f'{self.TEMPLATES_PATH}/common_all_files'
+        self.COMMON_MLFLOW_FILES_PATH = f'{self.TEMPLATES_PATH}/common_mlflow_files'
         self.AVAILABLE_TEMPLATES_PATH = f'{self.TEMPLATES_PATH}/available_templates.yml'
         self.AVAILABLE_TEMPLATES = load_yaml_file(self.AVAILABLE_TEMPLATES_PATH)
-        self.CWD = os.getcwd()
+        self.CWD = Path.cwd()
         self.creator_ctx = creator_ctx
 
-    def process_common_operations(self, skip_common_files=False, skip_fix_underline=False,
+    def process_common_operations(self, path: Path, skip_fix_underline=False,
                                   domain: str = None, subdomain: str = None, language: str = None,
                                   dot_mlf_core: OrderedDict = None) -> None:
         """
         Create all stuff that is common for mlf-core's template creation process; in detail those things are:
         create and copy common files, fix docs style, lint the project and ask whether the user wants to create a github repo.
         """
-        # create the common files and copy them into the templates directory (skip if flag is set)
-        if not skip_common_files:
-            self.create_common_files()
+        # create the common files and copy them into the templates directory
+        self.create_common_files(domain='all', common_files_path=self.COMMON_FILES_PATH)
+        # key in the switcher indicates, whether there are domain specific files or not (None)
+        domain_switcher = {
+            'mlflow': 'mlflow',
+            'package': None
+        }
+        # if project is a project with domain specific files, copy all common files for the domain of this project
+        try:
+            domain_specific_files = domain_switcher[self.creator_ctx.domain]
+        # this should only be the case, if mlf-core is developed further and new domains are added, therefore the error message
+        except KeyError:
+            print(f'[bold red]Unknown domain {self.creator_ctx.domain}! This domain seems to be new and must be added into the domain switcher!')
+            sys.exit(1)
+        if domain_specific_files:
+            self.create_common_files(domain=domain_specific_files, common_files_path=self.COMMON_MLFLOW_FILES_PATH)
 
         self.create_dot_mlf_core(template_version=self.creator_ctx.template_version)
 
@@ -71,14 +86,16 @@ class TemplateCreator:
             shutil.rmtree(tmp_project_path, ignore_errors=True)
 
         if subdomain:
-            print()
-            print(f'[bold blue]Please visit: https://mlf-core.readthedocs.io/en/latest/available_templates/available_templates.html'
+            print(f'\n[bold blue]Please visit: https://mlf-core.readthedocs.io/en/latest/available_templates/available_templates.html'
                   f'#{domain}-{subdomain}-{language} for more information about how to use your chosen template.')
         else:
-            print()
-            print(f'[bold blue]Please visit: https://mlf-core.readthedocs.io/en/latest/available_templates/available_templates.html'
+            print(f'\n[bold blue]Please visit: https://mlf-core.readthedocs.io/en/latest/available_templates/available_templates.html'
                   f'#{domain}-{language} for more information about how to use your chosen template.')
 
+        # do not move if path is current working directory or a directory named like the project in the current working directory (second is default case)
+        if path != self.CWD and path != Path(self.CWD / self.creator_ctx.project_slug_no_hyphen):
+            shutil.move(f'{self.CWD}/{self.creator_ctx.project_slug_no_hyphen}', f'{path}/{self.creator_ctx.project_slug_no_hyphen}')
+
     def create_template_without_subdomain(self, domain_path: str) -> None:
         """
         Creates a chosen template that does **not** have a subdomain.
@@ -87,7 +104,7 @@ class TemplateCreator:
         :param domain_path: Path to the template, which is still in cookiecutter format
         """
         # Target directory is already occupied -> overwrite?
-        occupied = os.path.isdir(f'{os.getcwd()}/{self.creator_ctx.project_slug}')
+        occupied = os.path.isdir(f'{self.CWD}/{self.creator_ctx.project_slug}')
         if occupied:
             self.directory_exists_warning()
 
@@ -114,13 +131,13 @@ class TemplateCreator:
         :param domain_path: Path to the template, which is still in cookiecutter format
         :param subdomain: Subdomain of the chosen template
         """
-        occupied = os.path.isdir(f'{os.getcwd()}/{self.creator_ctx.project_slug}')
+        occupied = os.path.isdir(f'{self.CWD}/{self.creator_ctx.project_slug}')
         if occupied:
             self.directory_exists_warning()
 
             # Confirm proceeding with overwriting existing directory
             if mlf_core_questionary_or_dot_mlf_core('confirm', 'Do you really want to continue?', default='Yes'):
-                delete_dir_tree(Path(f'{os.getcwd()}/{self.creator_ctx.project_slug}'))
+                delete_dir_tree(Path(f'{self.CWD}/{self.creator_ctx.project_slug}'))
                 cookiecutter(f'{domain_path}/{subdomain}_{self.creator_ctx.language.lower()}',
                              no_input=True,
                              overwrite_if_exists=True,
@@ -144,7 +161,7 @@ class TemplateCreator:
         :param subdomain: Subdomain of the chosen template
         :param framework: Chosen framework
         """
-        occupied = os.path.isdir(f'{os.getcwd()}/{self.creator_ctx.project_slug}')
+        occupied = os.path.isdir(f'{self.CWD}/{self.creator_ctx.project_slug}')
         if occupied:
             self.directory_exists_warning()
 
@@ -253,15 +270,17 @@ class TemplateCreator:
             self.creator_ctx.github_username = load_github_username()
             self.creator_ctx.creator_github_username = self.creator_ctx.github_username
 
-    def create_common_files(self) -> None:
+    def create_common_files(self, domain: str, common_files_path: str) -> None:
         """
-        This function creates a temporary directory for common files of all templates and applies cookiecutter on them.
+        Create a temporary directory for common files of a specified domain or all templates and apply cookiecutter on them.
         They are subsequently moved into the directory of the created template.
         """
+        log.debug('Creating common files.')
         dirpath = tempfile.mkdtemp()
-        copy_tree(f'{self.COMMON_FILES_PATH}', dirpath)
-        cwd_project = Path.cwd()
+        copy_tree(common_files_path, dirpath)
+        cwd_project = self.CWD
         os.chdir(dirpath)
+        log.debug(f'Cookiecuttering common files at {dirpath}')
         cookiecutter(dirpath,
                      extra_context={'full_name': self.creator_ctx.full_name,
                                     'email': self.creator_ctx.email,
@@ -269,20 +288,24 @@ class TemplateCreator:
                                     'domain': self.creator_ctx.domain,
                                     'project_name': self.creator_ctx.project_name,
                                     'project_slug': self.creator_ctx.project_slug,
+                                    'project_slug_no_hyphen': self.creator_ctx.project_slug_no_hyphen,
                                     'version': self.creator_ctx.version,
                                     'license': self.creator_ctx.license,
                                     'project_short_description': self.creator_ctx.project_short_description,
                                     'github_username': self.creator_ctx.github_username,
-                                    'creator_github_username': self.creator_ctx.creator_github_username},
+                                    'creator_github_username': self.creator_ctx.creator_github_username,
+                                    'framework': self.creator_ctx.language.capitalize() if domain == 'mlflow' else ''},
                      no_input=True,
                      overwrite_if_exists=True)
 
-        # recursively copy the common files directory content to the created project
-        copy_tree(f'{os.getcwd()}/common_files_util', f'{cwd_project}/{self.creator_ctx.project_slug}')
+        # copy the common files directory content to the created project
+        log.debug('Copying common files into the created project')
+        copy_tree(f'{Path.cwd()}/common_{domain}_files', f'{cwd_project}/{self.creator_ctx.project_slug}')
         # delete the tmp cookiecuttered common files directory
-        delete_dir_tree(Path(f'{Path.cwd()}/common_files_util'))
+        log.debug('Delete common files directory.')
+        delete_dir_tree(Path(f'{Path.cwd()}/common_{domain}_files'))
         shutil.rmtree(dirpath)
-        # change to recent cwd so lint etc can run properly
+        # change to recent cwd so lint can run properly
         os.chdir(str(cwd_project))
 
     def readthedocs_slug_already_exists(self, project_name: str) -> bool:
@@ -305,12 +328,12 @@ class TemplateCreator:
         If the directory is already a git directory within the same project, print error message and exit.
         Otherwise print a warning that a directory already exists and any further action on the directory will overwrite its contents.
         """
-        if is_git_repo(Path(f'{os.getcwd()}/{self.creator_ctx.project_slug}')):
-            print(f'[bold red]Error: A git project named {self.creator_ctx.project_slug} already exists at [green]{os.getcwd()}\n')
+        if is_git_repo(Path(f'{self.CWD}/{self.creator_ctx.project_slug}')):
+            print(f'[bold red]Error: A git project named {self.creator_ctx.project_slug} already exists at [green]{self.CWD}\n')
             print('[bold red]Aborting!')
             sys.exit(1)
         else:
-            print(f'[bold yellow]WARNING: [red]A directory named {self.creator_ctx.project_slug} already exists at [blue]{os.getcwd()}\n')
+            print(f'[bold yellow]WARNING: [red]A directory named {self.creator_ctx.project_slug} already exists at [blue]{self.CWD}\n')
             print('Proceeding now will overwrite this directory and its content!')
 
     def create_dot_mlf_core(self, template_version: str):
@@ -320,6 +343,7 @@ class TemplateCreator:
 
         :param template_version: Version of the specific template
         """
+        log.debug('Creating .mlf_core.yml file.')
         self.creator_ctx.template_version = f'{template_version} # <<MLF-CORE_NO_BUMP>>'
         self.creator_ctx.mlf_core_version = f'{mlf_core.__version__} # <<MLF-CORE_NO_BUMP>>'
         with open(f'{self.creator_ctx.project_slug}/.mlf_core.yml', 'w') as f:
